@@ -47,7 +47,7 @@ import zipfile
 from contextlib import contextmanager
 
 
-__version__ = '0.7'
+__version__ = '0.8'
 __author__ = 'Marius Gedminas <marius@gedmin.as>'
 __licence__ = 'GPL v2 or later' # or ask me for MIT
 __url__ = 'https://github.com/mgedmin/check-manifest'
@@ -410,5 +410,30 @@ def main():
         sys.exit(2)
 
 
+#
+# zest.releaser integration
+#
+
+def zest_releaser_check(data):
+    """Check the completeness of MANIFEST.in before the release.
+
+    This is an entry point for zest.releaser.  See the documentation at
+    https://pypi.python.org/pypi/zest.releaser/3.3#entrypoints-documentation
+    """
+    from zest.releaser.utils import ask
+    if not ask("Do you want to run check-manifest?"):
+        return
+    try:
+        if not check_manifest(data['workingdir']):
+            if not ask("MANIFEST.in is not in order. "
+                       " Do you want to continue despite that?", default=False):
+                sys.exit(1)
+    except Failure, e:
+        error(e)
+        if not ask("Something bad happened. "
+                   " Do you want to continue despite that?", default=False):
+            sys.exit(2)
+
+
 if __name__ == '__main__':
     main()
